[−][src]Enum pulldown_cmark::Tag
Tags for elements that can contain other elements.
Variants
ParagraphA paragraph of text and other inline elements.
Heading(u32)A heading. The field indicates the level of the heading.
BlockQuoteCodeBlock(CowStr<'a>)A code block. The value contained in the tag describes the language of the code, which may be empty.
List(Option<u64>)A list. If the list is ordered the field indicates the number of the first item. Contains only list items.
ItemA list item.
FootnoteDefinition(CowStr<'a>)A footnote definition. The value contained is the footnote's label by which it can be referred to.
Table(Vec<Alignment>)A table. Contains a vector describing the text-alignment for each of its columns.
TableHeadA table header. Contains only TableRows. Note that the table body starts immediately
after the closure of the TableHead tag. There is no TableBody tag.
TableRowA table row. Is used both for header rows as body rows. Contains only TableCells.
TableCellEmphasisStrongStrikethroughLink(LinkType, CowStr<'a>, CowStr<'a>)A link. The first field is the link type, the second the destination URL and the third is a title.
Image(LinkType, CowStr<'a>, CowStr<'a>)An image. The first field is the link type, the second the destination URL and the third is a title.